@@ -76,6 +76,6 @@ class SharedArtifactsManager():
 
         return ops.add_shared_artifact(project_id=project_id, 
                                         filename=filename, 
-                                        content_bytes=content_bytes,
+                                        filepath=filepath,
                                          num_bytes=num_bytes, 
                                          token=self.auth_provider.secret_api_key)
\ No newline at end of file
