@@ -26,8 +26,9 @@ def add_profile():
 	password = getpass.getpass(prompt='Password: ', stream=None) 
 	click.echo("Connecting...")
 	success, api_key_uuid = auth.fetch_secret_api_token(username, password)
+
 	if success:
-		click.echo(f'Added profile [{username}] in ~/.hectiqlab/credentials')
+		click.echo(f'Added profile [{username}] in {auth.tokens_path}')
 		try:
 			api_name = socket.gethostname()
 			res = ops.update_secret_api_token_name(api_key_uuid, name=api_name, token=auth.secret_api_key)
@@ -54,11 +55,11 @@ def artifacts(project_id):
 
 @cli.command()
 @click.option('-p', '--project_id', help='id of the project', required=True)
-@click.option('-f', '--filename', help='Name of the shared artifact', required=True)
-def post_artifact(project_id, filename):
+@click.option('-f', '--filepath', help='Name of the shared artifact', required=True)
+def post_artifact(project_id, filepath):
 	manager = SharedArtifactsManager()
 	click.echo('Pushing artifacts.')
-	manager.push_artifact(filename, project_id)
+	manager.push_artifact(filepath, project_id)
 	click.echo('Artifact pushed')
 
 @cli.command()
