@@ -23,7 +23,9 @@ class EventsManager():
         """
         def threading_method():
             res = ops.fetch_minimum_python_version()
-            required_version = res['version']
+            required_version = res.get('version')
+            if required_version is None:
+                return
             if version.parse(pyhectiqlab.__version__) < version.parse(required_version):
                 logger.error(f'Your pyhectiqlab version ({pyhectiqlab.__version__}) is obsolete (required: {required_version}).')
                 logger.error('Update with:')
